@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import IO, Dict, List, Union
 
+from botocore.response import StreamingBody
+
 from .literals import (
     ErrorCauseType,
     ExportStatusType,
@@ -135,7 +137,7 @@ class GetBlockResponseTypeDef(_RequiredGetBlockResponseTypeDef, _OptionalGetBloc
 GetDigestResponseTypeDef = TypedDict(
     "GetDigestResponseTypeDef",
     {
-        "Digest": Union[bytes, IO[bytes]],
+        "Digest": Union[bytes, IO[bytes], StreamingBody],
         "DigestTipAddress": "ValueHolderTypeDef",
     },
 )
